@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2024 OpenRCT2 developers
+ * Copyright (c) 2014-2025 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,15 +9,13 @@
 
 #pragma once
 
-#include "../common.h"
-
 #include <memory>
 
-enum class ADVERTISE_STATUS
+enum class AdvertiseStatus
 {
-    DISABLED,
-    UNREGISTERED,
-    REGISTERED,
+    disabled,
+    unregistered,
+    registered,
 };
 
 struct INetworkServerAdvertiser
@@ -26,8 +24,8 @@ struct INetworkServerAdvertiser
     {
     }
 
-    virtual ADVERTISE_STATUS GetStatus() const abstract;
-    virtual void Update() abstract;
+    virtual AdvertiseStatus GetStatus() const = 0;
+    virtual void Update() = 0;
 };
 
 [[nodiscard]] std::unique_ptr<INetworkServerAdvertiser> CreateServerAdvertiser(uint16_t port);
